@@ -1,7 +1,7 @@
 """forge specific entities class for imported entities
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -19,7 +19,7 @@ from cubes.file.entities import File as BaseFile
 from cubes.comment.entities import Comment as BaseComment
 from cubes.email.entities import Email as BaseEmail
 from cubes.tracker.entities import project, version, ticket
-from cubes.tracker.entities import ProjectItemMixIn, fixed_orderby_rql
+from cubes.tracker.entities import ProjectItemMixIn
 
 
 # project / extproject #########################################################
@@ -29,7 +29,7 @@ class ExtProject(AnyEntity):
     __regid__ = 'ExtProject'
     __permissions__ = ('developer', 'client')
 
-    fetch_attrs, fetch_order = fetch_config(['name', 'description', 'description_format'])
+    fetch_attrs, cw_fetch_order = fetch_config(['name', 'description', 'description_format'])
 
     def dc_title(self, format='text/plain'):
         return self.name
@@ -40,23 +40,6 @@ class Project(project.Project):
     __permissions__ = ('developer', 'client')
     fetch_attrs = project.Project.fetch_attrs + ('homepage', 'summary')
 
-    TICKET_DEFAULT_STATE_RESTR = 'S name IN ("open","done","waiting feedback","in-progress","validation pending")'
-
-    # number of columns to display
-    tickets_rql_nb_displayed_cols = 10
-    sort_defs = (('in_state', 'S'), ('num', 'VN'), ('type', 'TT'),
-                 ('priority', 'PR'))
-    def tickets_rql(self, limit=None):
-        return ('Any B,TT,NOW - CD, NOW - BMD, U,PR,S,C,V,group_concat(TN),BDF,BD,BC,VN,P,BT,CD,BMD,UL '
-                'GROUPBY B,TT,CD,PR,S,C,V,U,VN,BDF,BD,BC,P,BT,BMD,UL %s %s WHERE '
-                'B type TT, B priority PR, B in_state S, B creation_date CD, '
-                'B description_format BDF, B description BD, B load_left BC, '
-                'B title BT, B modification_date BMD, '
-                'B load C, T? tags B, T name TN, B done_in V?, V num VN, '
-                'B created_by U?, U login UL, B concerns P, P eid %%(x)s'
-                % (fixed_orderby_rql(self.sort_defs),
-                   limit and ' LIMIT %s' % limit or ''),
-                {'x': self.eid})
 
 
 class ProjectIFTIndexableAdapter(IFTIndexableAdapter):
@@ -121,31 +104,6 @@ class Version(version.Version):
                             progress_todo=progress_todo,
                             progress_done=progress_done)
 
-    # ui utilities ############################################################
-
-    # number of columns to display
-    tickets_rql_nb_displayed_cols = 8
-    sort_defs = (('in_state', 'S'), ('type', 'TT'), ('priority', 'PR'))
-    def tickets_rql(self):
-        """rql for tickets done / todo in this version"""
-        return ('Any B,TT,PR,S,C,AC,U,group_concat(TN), TI,D,DF,V '
-                'GROUPBY B,TT,PR,S,C,AC,U,TI,D,DF,V %s '
-                'WHERE B type TT, B priority PR, B load_left AC, B load C, '
-                'B in_state S, T? tags B, T name TN, B created_by U?,'
-                'B done_in V, V eid %%(x)s, '
-                'B title TI, B description D, B description_format DF'
-                % fixed_orderby_rql(self.sort_defs), {'x': self.eid})
-
-    defects_rql_nb_displayed_cols = 5
-    def defects_rql(self):
-        """rql for defects appeared in this version"""
-        return ('Any B,S,V,U,group_concat(TN), BT,BD,BDF '
-                'GROUPBY B,S,V,U,BT,BD,BDF ORDERBY S '
-                'WHERE B in_state S, T? tags B, T name TN, B created_by U?,'
-                'B done_in V?, B appeared_in X, X eid %(x)s, '
-                'B title BT, B description BD, B description_format BDF',
-                {'x': self.eid})
-
 
 class VersionIMileStoneAdapter(version.VersionIMileStoneAdapter):
 
@@ -236,7 +194,7 @@ class Comment(BaseComment):
             return None
 
 
-class File(ProjectItemMixIn, BaseFile):
+class File(BaseFile):
 
     @property
     def project(self):
