@@ -1,15 +1,14 @@
 """Forge cube hooks
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 
 from datetime import datetime
 
-from cubicweb import ValidationError
-from cubicweb.server.hook import Hook, Operation
+from cubicweb.server.hook import Hook
 from cubicweb.selectors import is_instance
 from cubicweb.server import hook
 
