@@ -17,7 +17,7 @@ Local permission (granted by project):
   * add documentation file, screenshots, ticket's attachment
 
 :organization: Logilab
-:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -28,7 +28,7 @@ from yams.buildobjs import (EntityType, RelationDefinition,
 
 from cubicweb.schema import (RQLVocabularyConstraint, RRQLExpression,
                              ERQLExpression, make_workflowable)
-from cubes.tracker.schemaperms import sexpr, xexpr, xrexpr, xorexpr, xperm, restricted_oexpr
+from cubes.localperms import sexpr, xexpr, xrexpr, xperm, restricted_oexpr
 
 from cubes.tracker.schema import Project, Ticket, Version, done_in
 from cubes.file.schema import File
@@ -202,9 +202,9 @@ File.__permissions__ = {
     'read':   ('managers', 'users', 'guests'),
     'add':    ('managers', 'staff',
                ERQLExpression('Y attachment X, Y is Email, U has_update_permission Y'),
-               xorexpr('attachment', 'File', 'developer', 'client'),
-               xorexpr('screenshot', 'File', 'developer', 'client'),
-               xorexpr('documented_by', 'File', 'developer', 'client'),),
+               xrexpr('attachment', 'File', 'developer', 'client', role='object'),
+               xrexpr('screenshot', 'File', 'developer', 'client', role='object'),
+               xrexpr('documented_by', 'File', 'developer', 'client', role='object'),),
     'update': ('managers', 'staff', 'owners',),
     'delete': ('managers', 'owners'),
     }
@@ -213,7 +213,7 @@ File.__permissions__ = {
 Card.__permissions__ = {
     'read':   ('managers', 'users', 'guests'),
     'add':    ('managers', 'staff',
-               xorexpr('documented_by', 'Card', 'developer', 'client'),
+               xrexpr('documented_by', 'Card', 'developer', 'client', role='object'),
                xrexpr('test_case_for', 'developer', 'client'),
                xrexpr('test_case_of', 'developer', 'client'),),
     'update': ('managers', 'staff', 'owners',),
