@@ -1,7 +1,7 @@
 """forge test application"""
 
 from cubicweb.devtools.testlib import AutomaticWebTest
-from cubicweb.devtools.testlib import vreg_instrumentize, print_untested_objects
+# from cubicweb.devtools.testlib import vreg_instrumentize, print_untested_objects
 
 
 class AutomaticWebTest(AutomaticWebTest):
