@@ -3,6 +3,17 @@ from cubicweb import devtools # needed to ensure cubes.tracker is importable
 
 from cubes.tracker.testutils import BaseMSTC, ms_test_init
 
+def setUpModule(*args):
+    global repo2, cnx2, repo3, cnx3
+    repo2, cnx2, repo3, cnx3, eids = ms_test_init(ThreeSourcesTC.datadir)
+
+def tearDownModule(*args):
+    cnx2.close()
+    repo2.shutdown()
+    cnx3.close()
+    repo3.shutdown()
+
+
 class ThreeSourcesTC(BaseMSTC):
     def test_projects_interested_in(self):
         rset = self.execute('Any P,N WHERE P name N, X interested_in P, X eid %(x)s', {'x': self.session.user.eid})
@@ -51,8 +62,6 @@ class ThreeSourcesTC(BaseMSTC):
         rset.rows[0][4] = 'STATE'
         self.assertEqual(rset.rows, [[self.ip1t1eid, u'bug', timedelta(0), u'normal', 'STATE', None, self.ip1v1eid, u'']])
 
-repo2, cnx2, repo3, cnx3, eids = ms_test_init(ThreeSourcesTC.datadir)
-
 if __name__ == '__main__':
     from logilab.common.testlib import unittest_main
     unittest_main()
