@@ -34,13 +34,9 @@ class ProjectTC(TrackerBaseTC):
                           ('refuse validation', 'not validated')]:
             iworkflowable.fire_transition(tr)
             self.commit()
-            ticket.clear_all_caches()
+            ticket.cw_clear_all_caches()
             self.assertEqual(iworkflowable.state, state)
 
-    def test_tickets_rql(self):
-        self.execute(self.cubicweb.active_tickets_rql()) # just check rql validity
-        self.execute(*self.cubicweb.tickets_rql()) # just check rql validity
-
     def test_download_box(self):
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
@@ -74,33 +70,33 @@ class ProjectTC(TrackerBaseTC):
         # manager user, in dev project
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('edit', actions.ModifyAction),
-                               ('managepermission', actions.ManagePermissionsAction),
-                               ('addrelated', actions.AddRelatedActions),
-                               ('delete', actions.DeleteAction),
-                               ('copy', actions.CopyAction),
-                               ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
-                               ('addticket', myproject.ProjectAddTicket),
-                               ('addversion', myproject.ProjectAddVersion),
-                               ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
-                               ('adddocumentationfile', myproject.ProjectAddDocumentationFile),
-                               ('addscreenshot', myproject.ProjectAddScreenshot),
-                               ('addtestcard', myproject.ProjectAddTestCard),
-                               ('addsubproject', myproject.ProjectAddSubProject),
-                               ('pvrestexport', document.ProjectVersionExportAction),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('edit', actions.ModifyAction),
+                              ('managepermission', actions.ManagePermissionsAction),
+                              ('addrelated', actions.AddRelatedActions),
+                              ('delete', actions.DeleteAction),
+                              ('copy', actions.CopyAction),
+                              ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
+                              ('addticket', myproject.ProjectAddTicket),
+                              ('addversion', myproject.ProjectAddVersion),
+                              ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
+                              ('adddocumentationfile', myproject.ProjectAddDocumentationFile),
+                              ('addscreenshot', myproject.ProjectAddScreenshot),
+                              ('addtestcard', myproject.ProjectAddTestCard),
+                              ('addsubproject', myproject.ProjectAddSubProject),
+                              ('pvrestexport', document.ProjectVersionExportAction),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
                               [])
         wf = self.cubicweb.cw_adapt_to('IWorkflowable').current_workflow
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'temporarily stop development', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                wf.transition_by_name('temporarily stop development').eid),
-                               (u'stop maintainance', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                wf.transition_by_name('stop maintainance').eid),
-                               (u'project moved', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                wf.transition_by_name('project moved').eid),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)
+                             [(u'temporarily stop development', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
+                               wf.transition_by_name('temporarily stop development').eid),
+                              (u'stop maintainance', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
+                               wf.transition_by_name('stop maintainance').eid),
+                              (u'project moved', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
+                               wf.transition_by_name('project moved').eid),
+                              (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)
                                ])
         # logilab user
         self.create_user(self.session, 'logilabien', ('staff', 'users'))
@@ -108,43 +104,43 @@ class ProjectTC(TrackerBaseTC):
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('edit', actions.ModifyAction),
-                               ('addrelated', actions.AddRelatedActions),
-                               ('copy', actions.CopyAction),
-                               ('addticket', myproject.ProjectAddTicket),
-                               ('addversion', myproject.ProjectAddVersion),
-                               ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
-                               ('adddocumentationfile', myproject.ProjectAddDocumentationFile),
-                               ('addscreenshot', myproject.ProjectAddScreenshot),
-                               ('addtestcard', myproject.ProjectAddTestCard),
-                               ('addsubproject', myproject.ProjectAddSubProject),
-                               ('pvrestexport', document.ProjectVersionExportAction),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('edit', actions.ModifyAction),
+                              ('addrelated', actions.AddRelatedActions),
+                              ('copy', actions.CopyAction),
+                              ('addticket', myproject.ProjectAddTicket),
+                              ('addversion', myproject.ProjectAddVersion),
+                              ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
+                              ('adddocumentationfile', myproject.ProjectAddDocumentationFile),
+                              ('addscreenshot', myproject.ProjectAddScreenshot),
+                              ('addtestcard', myproject.ProjectAddTestCard),
+                              ('addsubproject', myproject.ProjectAddSubProject),
+                              ('pvrestexport', document.ProjectVersionExportAction),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'temporarily stop development', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                wf.transition_by_name('temporarily stop development').eid),
-                               (u'stop maintainance', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                wf.transition_by_name('stop maintainance').eid),
-                               (u'project moved', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
-                                wf.transition_by_name('project moved').eid),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)
-                               ])
+                             [(u'temporarily stop development', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
+                               wf.transition_by_name('temporarily stop development').eid),
+                              (u'stop maintainance', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
+                               wf.transition_by_name('stop maintainance').eid),
+                              (u'project moved', u'http://testing.fr/cubicweb/project/cubicweb?treid=%s&vid=statuschange' %
+                               wf.transition_by_name('project moved').eid),
+                              (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)
+                              ])
         # guest user
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('addrelated', actions.AddRelatedActions),
-                               ('pvrestexport', document.ProjectVersionExportAction),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('addrelated', actions.AddRelatedActions),
+                              ('pvrestexport', document.ProjectVersionExportAction),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [])
+                             [])
         # std user, in dev project
         self.restore_connection()
         self.create_user(self.session, 'toto')
@@ -152,14 +148,14 @@ class ProjectTC(TrackerBaseTC):
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('addrelated', actions.AddRelatedActions),
-                               ('pvrestexport', document.ProjectVersionExportAction),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('addrelated', actions.AddRelatedActions),
+                              ('pvrestexport', document.ProjectVersionExportAction),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [])
+                             [])
         # std user with perm, in dev project
         self.restore_connection()# use the admin connection to create and link a permission
         self.grant_permission(self.session, self.cubicweb, 'users', 'developer',
@@ -170,20 +166,20 @@ class ProjectTC(TrackerBaseTC):
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('edit', actions.ModifyAction),
-                               ('addrelated', actions.AddRelatedActions),
-                               ('addticket', myproject.ProjectAddTicket),
-                               ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
-                               ('adddocumentationfile', myproject.ProjectAddDocumentationFile),
-                               ('addscreenshot', myproject.ProjectAddScreenshot),
-                               ('addtestcard', myproject.ProjectAddTestCard),
-                               ('pvrestexport', document.ProjectVersionExportAction),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('edit', actions.ModifyAction),
+                              ('addrelated', actions.AddRelatedActions),
+                              ('addticket', myproject.ProjectAddTicket),
+                              ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
+                              ('adddocumentationfile', myproject.ProjectAddDocumentationFile),
+                              ('addscreenshot', myproject.ProjectAddScreenshot),
+                              ('addtestcard', myproject.ProjectAddTestCard),
+                              ('pvrestexport', document.ProjectVersionExportAction),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [])
+                             [])
         # std user with client perm, in dev project
         self.restore_connection()# use the admin connection to create and link a permission
         self.grant_permission(self.session, self.cubicweb, 'users', 'client',
@@ -195,21 +191,21 @@ class ProjectTC(TrackerBaseTC):
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('edit', actions.ModifyAction),
-                               ('addrelated', actions.AddRelatedActions),
-                               ('addticket', myproject.ProjectAddTicket),
-                               ('addversion', myproject.ProjectAddVersion),
-                               ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
-                               ('adddocumentationfile', myproject.ProjectAddDocumentationFile),
-                               ('addscreenshot', myproject.ProjectAddScreenshot),
-                               ('addtestcard', myproject.ProjectAddTestCard),
-                               ('pvrestexport', document.ProjectVersionExportAction),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('edit', actions.ModifyAction),
+                              ('addrelated', actions.AddRelatedActions),
+                              ('addticket', myproject.ProjectAddTicket),
+                              ('addversion', myproject.ProjectAddVersion),
+                              ('adddocumentationcard', myproject.ProjectAddDocumentationCard),
+                              ('adddocumentationfile', myproject.ProjectAddDocumentationFile),
+                              ('addscreenshot', myproject.ProjectAddScreenshot),
+                              ('addtestcard', myproject.ProjectAddTestCard),
+                              ('pvrestexport', document.ProjectVersionExportAction),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [])
+                             [])
         # manager user, moved project
         self.restore_connection()
         self.cubicweb.cw_adapt_to('IWorkflowable').fire_transition('project moved')
@@ -217,19 +213,19 @@ class ProjectTC(TrackerBaseTC):
         req = self.request()
         rset = req.execute('Any X WHERE X is Project, X name "cubicweb"')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('edit', actions.ModifyAction),
-                               ('managepermission', actions.ManagePermissionsAction),
-                               ('addrelated', actions.AddRelatedActions),
-                               ('delete', actions.DeleteAction),
-                               ('copy', actions.CopyAction),
-                               ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
-                               ('pvrestexport', document.ProjectVersionExportAction),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('edit', actions.ModifyAction),
+                              ('managepermission', actions.ManagePermissionsAction),
+                              ('addrelated', actions.AddRelatedActions),
+                              ('delete', actions.DeleteAction),
+                              ('copy', actions.CopyAction),
+                              ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
+                              ('pvrestexport', document.ProjectVersionExportAction),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'view history', u'http://testing.fr/cubicweb/project/cubicweb?vid=wfhistory')])
+                             [(u'view history', u'http://testing.fr/cubicweb/project/cubicweb?vid=wfhistory')])
 
     def test_doap(self):
         self.create_version('0.1.0')
@@ -333,7 +329,7 @@ class TicketTC(TrackerBaseTC):
         rset = req.execute('Any X WHERE X is Ticket')
         _ticket = rset.get_entity(0, 0)
         teid = rset[0][0]
-        self.failUnlessEqual(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -352,17 +348,17 @@ class TicketTC(TrackerBaseTC):
                                 % (teid, teid))])
         wf = self.t1.cw_adapt_to('IWorkflowable').current_workflow
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'start', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('start').eid)),
-                               (u'reject', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('reject').eid)),
-                               (u'done', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('done').eid)),
-                               (u'deprecate', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('deprecate').eid)),
-                               (u'wait for feedback', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('wait for feedback').eid)),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)])
+                             [(u'start', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('start').eid)),
+                              (u'reject', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('reject').eid)),
+                              (u'done', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('done').eid)),
+                              (u'deprecate', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('deprecate').eid)),
+                              (u'wait for feedback', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('wait for feedback').eid)),
+                              (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid)])
         movetonext = self.action_submenu(req, rset, 'movetonext')
         self.assertEqual(len(movetonext), 1)
         self.assertEqual(movetonext[0][0], '0.0.0')
@@ -370,19 +366,19 @@ class TicketTC(TrackerBaseTC):
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('addrelated', actions.AddRelatedActions),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('addrelated', actions.AddRelatedActions),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [])
+                             [])
         self.restore_connection()
         req = self.request()
         self.t1.cw_adapt_to('IWorkflowable').fire_transition('done')
         self.commit()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.failUnlessEqual(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -399,39 +395,39 @@ class TicketTC(TrackerBaseTC):
                                 'http://testing.fr/cubicweb/add/Card?__linkto=test_case_for%%3A%s%%3Asubject&__redirectpath=ticket%%2F%s&__redirectvid='
                                 % (teid, teid))])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'ask validation', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('ask validation').eid)),
-                               (u'reopen', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('reopen').eid)),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid),
-                               (u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
+                             [(u'ask validation', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('ask validation').eid)),
+                              (u'reopen', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('reopen').eid)),
+                              (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid),
+                              (u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('addrelated', actions.AddRelatedActions),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('addrelated', actions.AddRelatedActions),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
+                             [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.restore_connection()
         self.t1.cw_adapt_to('IWorkflowable').fire_transition('ask validation')
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'resolve', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('resolve').eid)),
-                               (u'refuse validation', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
-                                (self.t1.eid, wf.transition_by_name('refuse validation').eid)),
-                               (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid),
-                               (u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
+                             [(u'resolve', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('resolve').eid)),
+                              (u'refuse validation', u'http://testing.fr/cubicweb/ticket/%s?treid=%s&vid=statuschange' %
+                               (self.t1.eid, wf.transition_by_name('refuse validation').eid)),
+                              (u'view workflow', u'http://testing.fr/cubicweb/workflow/%s'  % wf.eid),
+                              (u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.t1.cw_adapt_to('IWorkflowable').fire_transition('resolve')
         self.commit()
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
-        self.failUnlessEqual(self.pactions(req, rset),
+        self.assertListEqual(self.pactions(req, rset),
                              [('workflow', workflow.WorkflowActions),
                               ('edit', actions.ModifyAction),
                               ('managepermission', actions.ManagePermissionsAction),
@@ -441,25 +437,25 @@ class TicketTC(TrackerBaseTC):
                               ('actionsbox_notifications_mgmt', nosylist.INosyListManageNotificationsAction),
                               ('reply_comment', commentactions.AddCommentAction)])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [('add Ticket attachment File subject',
-                                'http://testing.fr/cubicweb/add/File?__linkto=attachment%%3A%s%%3Aobject&__redirectpath=ticket%%2F%s&__redirectvid='
-                                % (teid, teid)),
-                               ('add Card test_case_for Ticket object',
-                                'http://testing.fr/cubicweb/add/Card?__linkto=test_case_for%%3A%s%%3Asubject&__redirectpath=ticket%%2F%s&__redirectvid='
-                                % (teid, teid))])
+                             [('add Ticket attachment File subject',
+                               'http://testing.fr/cubicweb/add/File?__linkto=attachment%%3A%s%%3Aobject&__redirectpath=ticket%%2F%s&__redirectvid='
+                               % (teid, teid)),
+                              ('add Card test_case_for Ticket object',
+                               'http://testing.fr/cubicweb/add/Card?__linkto=test_case_for%%3A%s%%3Asubject&__redirectpath=ticket%%2F%s&__redirectvid='
+                               % (teid, teid))])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
+                             [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
         self.login('anon')
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
         self.assertListEqual(self.pactions(req, rset),
-                              [('workflow', workflow.WorkflowActions),
-                               ('addrelated', actions.AddRelatedActions),
-                               ])
+                             [('workflow', workflow.WorkflowActions),
+                              ('addrelated', actions.AddRelatedActions),
+                              ])
         self.assertListEqual(self.action_submenu(req, rset, 'addrelated'),
-                              [])
+                             [])
         self.assertListEqual(self.action_submenu(req, rset, 'workflow'),
-                              [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
+                             [(u'view history', u'http://testing.fr/cubicweb/ticket/%s?vid=wfhistory' % self.t1.eid)])
 
     def test_state_change_on_version_publishing(self):
         v2 = self.execute('INSERT Version V: V num "0.0.1", V version_of P '
@@ -468,17 +464,17 @@ class TicketTC(TrackerBaseTC):
         self.commit()
         t1iwf = self.t1.cw_adapt_to('IWorkflowable')
         t1iwf.fire_transition('done')
-        self.t1.clear_all_caches()
+        self.t1.cw_clear_all_caches()
         self.assertEqual(t1iwf.state, 'done')
         self.commit()
-        v2.clear_all_caches()
+        v2.cw_clear_all_caches()
         v2._cw = self.request()
         v2iwf = v2.cw_adapt_to('IWorkflowable')
         self.assertEqual(v2iwf.state, 'dev')
-        v2.clear_all_caches()
+        v2.cw_clear_all_caches()
         v2iwf.change_state('published')
         self.commit()
-        self.t1.clear_all_caches()
+        self.t1.cw_clear_all_caches()
         self.assertEqual(t1iwf.state, 'validation pending')
 
     def test_version_publishing_cant_change_ticket_state(self):
@@ -491,8 +487,8 @@ class TicketTC(TrackerBaseTC):
         # -  change ticket status
         t1iwf= self.t1.cw_adapt_to('IWorkflowable')
         t1iwf.fire_transition('done')
-        self.t1.clear_all_caches()
-        self.v.clear_all_caches()
+        self.t1.cw_clear_all_caches()
+        self.v.cw_clear_all_caches()
         self.assertEqual(t1iwf.state, 'done')
         # -  Remove permission on the ticket for the clients
         self.execute('DELETE X require_permission P WHERE X eid %s' % self.t1.eid)
