@@ -1,28 +1,53 @@
 """views for Project entities
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 _ = unicode
 
+from logilab.common.decorators import monkeypatch
 from logilab.mtconverter import xml_escape
 
 from cubicweb.selectors import one_line_rset, score_entity, is_instance
 from cubicweb.view import EntityView
-from cubicweb import tags, uilib
+from cubicweb import tags
 from cubicweb.web import uicfg, action
-from cubicweb.web.views import primary, tabs, baseviews
-
-from cubes.tracker.views import project as tracker
+from cubicweb.web.views import primary, tabs, baseviews, tableview
 
 from cubes.testcard import views as testcard
+from cubes.tracker.views import fixed_orderby_rql, project as tracker
+
 
 tracker.ProjectStatsView.default_rql = (
     'Any P, PN WHERE P is Project, P name PN, '
     'P in_state S, S name "active development"')
 
+idx = tracker.ProjectTicketsTable.columns.index('in_state')
+tracker.ProjectTicketsTable.columns.insert(idx+1, 'load')
+tracker.ProjectTicketsTable.columns.append('tags')
+tracker.ProjectTicketsTable.column_renderers['tags'] = \
+    tableview.RelationColRenderer(role='object')
+
+tracker.ProjectTicketsTab.TICKET_DEFAULT_STATE_RESTR \
+    = 'S name IN ("open","done","waiting feedback","in-progress","validation pending")'
+
+@monkeypatch(tracker.ProjectTicketsTab)
+def tickets_rql(self):
+    # prefetch everything we can for optimization
+    return ('Any T,TTI,TT,TP,TD,TDF,TCD,TMD,TL,S,SN,V,VN,U,UL %s WHERE '
+            'T title TTI, T type TT, T priority TP, '
+            'T description TD, T description_format TDF, '
+            'T creation_date TCD, T modification_date TMD, '
+            'T load TL,'
+            'T in_state S, S name SN, '
+            'T done_in V?, V num VN, '
+            'T created_by U?, U login UL, '
+            'T concerns P, P eid %%(x)s'
+            % fixed_orderby_rql(self.SORT_DEFS))
+
+
 # primary view and tabs ########################################################
 
 class ExtProjectPrimaryView(primary.PrimaryView):
@@ -127,6 +152,7 @@ class ProjectOutOfContextView(tracker.ProjectOutOfContextView):
             self.w(u'&nbsp;')
             self.w(xml_escape(entity.summary))
 
+
 # Project actions #############################################################
 
 class ProjectAddRelatedAction(action.LinkToEntityAction):
