@@ -1,7 +1,7 @@
 """forge specific index view
 
 :organization: Logilab
-:copyright: 2006-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -12,8 +12,7 @@ from logilab.mtconverter import xml_escape
 from cubicweb.web.views import startup
 
 
-class IndexView(startup.ManageView):
-    __regid__ = 'index'
+class IndexView(startup.IndexView):
     title = _('Index')
     add_etype_links = ('Project',)
 
@@ -34,21 +33,16 @@ class IndexView(startup.ManageView):
         _ = self._cw._
         w = self.w
         user = self._cw.user
-        if not user.matching_groups(('managers', 'staff', 'users')):
+        rset = self._cw.execute('Card X WHERE X wikiid "index"')
+        if not user.matching_groups('users'):
             w(u'<div>')
-            self._main_index()
+            if rset:
+                self.wview('inlined', rset, row=0)
             w(u'</div>')
         else:
             self._cw.add_css('cubes.forge.css')
             w(u'<div class="quickLinks">')
-            w(u'<ul class="createLink">')
-            for etype in self.add_etype_links:
-                eschema = self._cw.vreg.schema.eschema(etype)
-                if eschema.has_perm(self._cw, 'add'):
-                    w(u'<li><a href="%s">%s</a></li>' % (
-                            self._cw.build_url('add/%s' % eschema),
-                            self._cw.__('add a %s' % eschema).capitalize()))
-            w(u'</ul>')
+            self.create_links()
             w(u'<div class="hr">&nbsp;</div>')
             # XXX sort
             # XXX bad title (there may be blogs in there...)
@@ -71,13 +65,23 @@ class IndexView(startup.ManageView):
             w(u'<p><a href="%s">%s</a></p>' % (self._cw.build_url('project'),
                                                _('view all active projects')))
             w(u'</div>')
+            if user.matching_groups('managers'):
+                self.w(u'<div class="hr">&#160;</div>')
+                if rset:
+                    href = rset.get_entity(0, 0).absolute_url(vid='edition')
+                    label = self._cw._('edit the index page')
+                else:
+                    href = self._cw.build_url('view', vid='creation', etype='Card', wikiid='index')
+                    label = self._cw._('create an index page')
+                self.w(u'<br/><a href="%s">%s</a>\n' % (xml_escape(href), label))
             w(u'</div>')
 
     def _right_section(self):
         user = self._cw.user; _ = self._cw._; w = self.w
-        if not user.matching_groups(('managers', 'staff', 'users')):
+        if not user.matching_groups('users'):
             w(u'<div>')
-            self.folders()
+            w(u'<h2>%s</h2>\n' % self._cw._('Browse by category'))
+            self._cw.vreg['views'].select('tree', self._cw).render(w=w, maxlevel=1)
             w(u'</div>')
         w(u'</td><td style="width: 50%;">')
         # projects the user is subscribed to
@@ -88,8 +92,6 @@ class IndexView(startup.ManageView):
             self.wview('table', rset, 'null',
                        headers=[_(u'Recent tickets in my projects'), _(u'Date'), _(u'Project')],
                        subvid='incontext', displayactions=False)
-
-
         # tickets
         if user.is_in_group('guests'):
             rql = 'Any X, NOW - CD, P ORDERBY CD DESC LIMIT 5 WHERE X concerns P, X creation_date CD'
@@ -114,7 +116,7 @@ class IndexView(startup.ManageView):
                     'onmouseout=\"$(this).removeClass(\'highlighted\')\" ' \
                     'class="seemore" href="%s">%s</a>' %
                    (xml_escape(self._cw.build_url('view', rql=rql, vid='table', subvid='outofcontext')),
-                    self._cw._(u'All upcoming versions...'))) 
+                    self._cw._(u'All upcoming versions...')))
         # latest releases
         rset = self._cw.execute(self.latest_releases)
         self.wview('table', rset, 'null',
