@@ -7,10 +7,9 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from logilab.mtconverter import xml_escape
-from cubicweb.web import component, box
-from cubicweb.web.views import tabs, primary
-from cubicweb.selectors import one_line_rset, is_instance, has_related_entities
+from cubicweb.web import component
+from cubicweb.web.views import tabs
+from cubicweb.selectors import one_line_rset, is_instance
 
 class TicketTestCardCtxComponent(component.RelatedObjectsCtxComponent):
     """display project's test cards"""
