@@ -1,18 +1,21 @@
 """views for Project entities
 
 :organization: Logilab
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
+:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), license is LGPL.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 _ = unicode
 
+from logilab.common.decorators import monkeypatch
+
 from cubicweb.selectors import is_instance
 from cubicweb.view import EntityView
-from cubicweb.web import uicfg, component
-from cubicweb.web.views import baseviews
+from cubicweb.web import uicfg
+from cubicweb.web.views import baseviews, tableview
+
+from cubes.tracker.views import fixed_orderby_rql, version as tracker
 
-from cubes.tracker.views import version as tracker
 
 _pvs = uicfg.primaryview_section
 for attr in ('progress_target', 'progress_done', 'progress_todo'):
@@ -20,6 +23,31 @@ for attr in ('progress_target', 'progress_done', 'progress_todo'):
 
 tracker.VersionPrimaryView.tabs.append(_('forge.version.burndown_tab'))
 
+idx = tracker.VersionTicketsTable.columns.index('in_state')
+tracker.VersionTicketsTable.columns.insert(idx+1, 'load')
+tracker.VersionTicketsTable.columns.insert(idx+2, 'load_left')
+tracker.VersionTicketsTable.columns.append('tags')
+tracker.VersionTicketsTable.column_renderers['tags'] = tableview.RelationColRenderer(role='object')
+
+@monkeypatch(tracker.VersionPrimaryTab)
+def tickets_rql(self):
+    # prefetch everything we can for optimization
+    return ('Any T,TTI,TT,TP,TD,TDF,TCD,TMD,TL,TLL,S,SN %s WHERE '
+            'T title TTI, T type TT, T priority TP, '
+            'T description TD, T description_format TDF, '
+            'T creation_date TCD, T modification_date TMD, '
+            'T load TL, T load_left TLL, '
+            'T in_state S, S name SN, '
+            'T %s V, V eid %%(x)s'
+            % (fixed_orderby_rql(self.SORT_DEFS), self.TICKETS_RELATION))
+
+
+class VersionProgressTableView(tracker.VersionProgressTableView):
+    column_renderers = tracker.VersionProgressTableView.column_renderers.copy()
+    column_renderers['cost'] = column_renderers['cost'].copy()
+    column_renderers['cost'].header = _('load')
+
+
 # we don't want IDownloadable oneline view for version
 class VersionOneLineView(baseviews.OneLineView):
     __select__ = is_instance('Version')
@@ -53,17 +81,6 @@ class VersionBurndownChartTab(EntityView):
             self.wview('burndown_chart', tickets_rset, width=800, height=500)
 
 
-class VersionProgressTableView(tracker.VersionProgressTableView):
-    columns = (_('project'), _('milestone'), _('state'), _('planned_start'),
-               _('planned_delivery'),
-               _('cost'), _('progress'),
-               _('depends_on'), _('todo_by'))
-
-    def header_for_cost(self, ecls):
-        """``cost`` column cell renderer"""
-        return self._cw._('load')
-
-
 def registration_callback(vreg):
     vreg.register_all(globals().values(), __name__, (VersionProgressTableView,))
     vreg.register_and_replace(VersionProgressTableView,
